( cd usr/lib64 ; rm -rf libxrx.so.0 )
( cd usr/lib64 ; ln -sf libxrx.so.0.0.0 libxrx.so.0 )
( cd usr/lib64 ; rm -rf libxrx.so )
( cd usr/lib64 ; ln -sf libxrx.so.0.0.0 libxrx.so )
( cd usr/lib64 ; rm -rf libxrxnest.so.0 )
( cd usr/lib64 ; ln -sf libxrxnest.so.0.0.0 libxrxnest.so.0 )
( cd usr/lib64 ; rm -rf libxrxnest.so )
( cd usr/lib64 ; ln -sf libxrxnest.so.0.0.0 libxrxnest.so )
